==> flink-1.14.4-src.tgz: flink-1.14.4/flink-table/flink-table-planner/src/main/scala/org/apache/flink/table/planner/calcite/FlinkContextImpl.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.calcite

import org.apache.flink.table.api.TableConfig
import org.apache.flink.table.catalog.{CatalogManager, FunctionCatalog}

class FlinkContextImpl(
    inBatchMode: Boolean,
    tableConfig: TableConfig,
    functionCatalog: FunctionCatalog,
    catalogManager: CatalogManager,
    toRexFactory: SqlExprToRexConverterFactory)
  extends FlinkContext {

  override def isBatchMode: Boolean = inBatchMode

  override def getTableConfig: TableConfig = tableConfig

  override def getFunctionCatalog: FunctionCatalog = functionCatalog

  override def getCatalogManager: CatalogManager = catalogManager

  override def getSqlExprToRexConverterFactory: SqlExprToRexConverterFactory = toRexFactory
}

==> flink-1.15.0-src.tgz: flink-1.15.0/flink-table/flink-table-planner/src/main/scala/org/apache/flink/table/planner/calcite/FlinkContextImpl.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.calcite

import org.apache.flink.table.api.TableConfig
import org.apache.flink.table.catalog.{CatalogManager, FunctionCatalog}
import org.apache.flink.table.module.ModuleManager

class FlinkContextImpl(
    inBatchMode: Boolean,
    tableConfig: TableConfig,
    moduleManager: ModuleManager,
    functionCatalog: FunctionCatalog,
    catalogManager: CatalogManager,
    toRexFactory: SqlExprToRexConverterFactory)
  extends FlinkContext {

  override def isBatchMode: Boolean = inBatchMode

  override def getTableConfig: TableConfig = tableConfig

  override def getModuleManager: ModuleManager = moduleManager

  override def getFunctionCatalog: FunctionCatalog = functionCatalog

  override def getCatalogManager: CatalogManager = catalogManager

  override def getSqlExprToRexConverterFactory: SqlExprToRexConverterFactory = toRexFactory
}
